pub struct AppApi { /* private fields */ }Expand description
Stable app-facing high-level facade for common bot workflows.
Implementations
Sourceimpl AppApi
impl AppApi
Sourcepub fn moderation(&self) -> ModerationApi
pub fn moderation(&self) -> ModerationApi
Dedicated moderation/admin facade for governance actions.
Sourcepub fn text(
&self,
chat_id: impl Into<ChatId>,
text: impl Into<String>,
) -> Result<TextSendBuilder>
pub fn text( &self, chat_id: impl Into<ChatId>, text: impl Into<String>, ) -> Result<TextSendBuilder>
Starts a high-level text send to a target chat.
Sourcepub fn reply(
&self,
update: &Update,
text: impl Into<String>,
) -> Result<TextSendBuilder>
pub fn reply( &self, update: &Update, text: impl Into<String>, ) -> Result<TextSendBuilder>
Starts a high-level text send using the canonical reply chat derived from an update.
Sourcepub async fn send_text(
&self,
chat_id: impl Into<ChatId>,
text: impl Into<String>,
) -> Result<Message>
pub async fn send_text( &self, chat_id: impl Into<ChatId>, text: impl Into<String>, ) -> Result<Message>
Sends plain text to a target chat.
Sourcepub async fn reply_text(
&self,
update: &Update,
text: impl Into<String>,
) -> Result<Message>
pub async fn reply_text( &self, update: &Update, text: impl Into<String>, ) -> Result<Message>
Replies to a chat derived from an incoming update.