Store

Struct Store 

pub struct Store<T> { /* private fields */ }

Implementations

Source

impl<P: 'static> Store<P>

pub fn new(path: impl AsRef<Path>, provider: P) -> Self

pub fn resource<T>( &mut self, id: &'static str, local_definition: T, ) -> Result<StoreResource<T, T::Output>, Error>
where T: Resource<Provider = P>,

Defines a resource.

Produces two graph nodes:

  1. Depending on the result of compairing local_definition to the one on file (if it exists), either:
    • creates the resource on the platform
    • updates the resource on the platform
    • loads the resource from a file
  2. Stores the resource to a file

To import an existing resource from a platform, use Store::import.

pub fn import<T>( &mut self, id: &'static str, local_definition: T, ) -> Result<StoreResource<T, T::Output>, Error>
where T: Resource<Provider = P>,

Defines a pre-existing resource, importing it from the platform.

Produces two graph nodes:

  1. Import the resource from the platform, resulting in the resource
  2. Store the value to a file

This only needs to be used once in your infrastructure command. After the resource is imported and stored to a file it is recommended you make a code change to use Store::resource.

pub fn load<T>( &mut self, id: &'static str, local_definition: T, remote_definition: T::Output, force_overwrite: bool, ) -> Result<StoreResource<T, T::Output>, Error>
where T: Resource<Provider = P>,

Defines a pre-existing resource, directly writing it to file, without querying the platform.

Produces two graph nodes:

  1. Load the value (noop)
  2. Store the value
Errors

Errs if force_overwrite is false and a stored resource already exists. This is done to prevent accidental clobbering.

pub fn destroy<T>( &mut self, id: &'static str, ) -> Result<DestroyResource<T>, Error>
where T: Resource<Provider = P>,

Destroys a resource.

pub fn get_schedule_string(&self) -> Result<String, Error>

pub fn save_apply_graph(&self, path: impl AsRef<Path>) -> Result<(), Error>

pub async fn apply(&mut self) -> Result<(), Error>