Module utils

Module utils 

Utilities for working with teleform.

Functions

sha256_digest
Returns the sha256 digest of the file at the given path if it exists. If the file does not exist it returns Ok(None).