pub struct BlockingDiceSendBuilder { /* private fields */ }Expand description
Stable builder for high-level dice sends on the blocking app facade.
Blocking mirror of DiceSendBuilder.
Implementations
Sourceimpl BlockingDiceSendBuilder
impl BlockingDiceSendBuilder
Sourcepub fn reply_markup(self, reply_markup: impl Into<ReplyMarkup>) -> Self
pub fn reply_markup(self, reply_markup: impl Into<ReplyMarkup>) -> Self
Attaches reply markup such as an inline keyboard.
Sourcepub fn suggested_post_parameters(
self,
suggested_post_parameters: SuggestedPostParameters,
) -> Self
pub fn suggested_post_parameters( self, suggested_post_parameters: SuggestedPostParameters, ) -> Self
Sets suggested post parameters for direct messages chats.
Sourceimpl BlockingDiceSendBuilder
impl BlockingDiceSendBuilder
Sourcepub fn reply_parameters(self, reply_parameters: ReplyParameters) -> Self
pub fn reply_parameters(self, reply_parameters: ReplyParameters) -> Self
Sets explicit reply parameters.
Sourcepub fn reply_to_message(self, message_id: MessageId) -> Self
pub fn reply_to_message(self, message_id: MessageId) -> Self
Replies to a concrete message by id.
Sourcepub fn business_connection_id(
self,
business_connection_id: impl Into<String>,
) -> Self
pub fn business_connection_id( self, business_connection_id: impl Into<String>, ) -> Self
Sends on behalf of a Telegram Business connection.
Sourcepub fn message_thread_id(self, message_thread_id: i64) -> Self
pub fn message_thread_id(self, message_thread_id: i64) -> Self
Targets a forum topic / message thread when applicable.
Sourcepub fn direct_messages_topic_id(self, direct_messages_topic_id: i64) -> Self
pub fn direct_messages_topic_id(self, direct_messages_topic_id: i64) -> Self
Targets a direct messages topic when sending to a channel direct messages chat.
Sourcepub fn disable_notification(self, enabled: bool) -> Self
pub fn disable_notification(self, enabled: bool) -> Self
Sends silently when true.
Sourcepub fn protect_content(self, enabled: bool) -> Self
pub fn protect_content(self, enabled: bool) -> Self
Protects the sent content from forwarding and saving when true.
Sourcepub fn allow_paid_broadcast(self, enabled: bool) -> Self
pub fn allow_paid_broadcast(self, enabled: bool) -> Self
Allows high-throughput paid broadcast sends when true.
Sourcepub fn message_effect_id(self, message_effect_id: impl Into<String>) -> Self
pub fn message_effect_id(self, message_effect_id: impl Into<String>) -> Self
Adds a Telegram message effect to the sent content.
Sourcepub fn into_request(self) -> SendDiceRequest
pub fn into_request(self) -> SendDiceRequest
Returns the typed request for lower-level reuse or inspection.